Module runtime

Module runtime 

Re-exports the lightweight in-house runtime.

Structs

BroadcastReceiver
Receiving side of a broadcast channel.
BroadcastSender
Broadcast sender that clones each message for all active subscribers.
JoinHandle
Join handle returned by spawn.

Functions

block_on
Runs a future to completion on the current thread.
broadcast
Creates a broadcast channel and returns the first receiver.
spawn
Spawns a future onto a dedicated worker thread.
try_spawn
Tries to spawn a future onto a dedicated worker thread.