pub enum ApiProfilePhase {
SerializeParams,
Transport,
DeserializeResponse,
DecodeBinary,
}Expand description
Fine-grained client request phase used by optional profiling hooks.
Variants
SerializeParams
Time spent serializing request parameters before transport I/O starts.
Transport
Time spent waiting on the underlying transport and upstream worker.
DeserializeResponse
Time spent decoding a typed JSON response after transport I/O completes.
DecodeBinary
Time spent decoding a binary payload wrapper such as base64.
Implementations