pub struct JsonRpcConnectionOptions {
pub request_timeout: Option<Duration>,
pub outbound_capacity: usize,
pub observer: Option<Arc<dyn CorsaObserver>>,
}Expand description
Runtime policy applied to a JsonRpcConnection.
Fields
request_timeout: Option<Duration>Maximum time to wait for a response before surfacing a timeout.
outbound_capacity: usizeMaximum number of queued outbound messages waiting on the writer thread.
observer: Option<Arc<dyn CorsaObserver>>Optional observer for structured transport events.
Implementations
Sourceimpl JsonRpcConnectionOptions
impl JsonRpcConnectionOptions
Sourcepub fn new() -> JsonRpcConnectionOptions
pub fn new() -> JsonRpcConnectionOptions
Creates the default production-oriented JSON-RPC transport policy.
Sourcepub fn with_request_timeout(
self,
timeout: Option<Duration>,
) -> JsonRpcConnectionOptions
pub fn with_request_timeout( self, timeout: Option<Duration>, ) -> JsonRpcConnectionOptions
Sets the per-request timeout.
Sourcepub fn with_outbound_capacity(self, capacity: usize) -> JsonRpcConnectionOptions
pub fn with_outbound_capacity(self, capacity: usize) -> JsonRpcConnectionOptions
Sets the maximum number of queued outbound messages.
Sourcepub fn with_observer(
self,
observer: Arc<dyn CorsaObserver>,
) -> JsonRpcConnectionOptions
pub fn with_observer( self, observer: Arc<dyn CorsaObserver>, ) -> JsonRpcConnectionOptions
Sets the observer used for structured transport events.
Sourcepub fn with_observer_if_some(
self,
observer: Option<Arc<dyn CorsaObserver>>,
) -> JsonRpcConnectionOptions
pub fn with_observer_if_some( self, observer: Option<Arc<dyn CorsaObserver>>, ) -> JsonRpcConnectionOptions
Sets the observer when one is available.